/****************************************************************************
Copyright (C) 2010 Laszlo Simon <laszlo.simon@gmail.com>
This file is part of the QMETRICS project.

QMETRICS is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation version 3 of the License.
,
QMETRICS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with QMETRICS. If not, see <http://www.gnu.org/licenses/>.

See http://www.illusions.hu for further details.
*****************************************************************************/

#include <iostream>
#include <cstring>
#include <cstdlib>
#include <cstdio>
#include <string>

#include "cm_units.h"
#include "cm_tabs.h"

using namespace std;

static void printHelp(void)
{    
  printf("CMetrics - Commandline Unit Converter\n"
         "Usage:\n"
         "  cmetrics value unit targetunit\n"
         "\n"
         "Units:\n");

  for (int tab = 0; tab < eTabNum; tab++)
  {
    printf("  %s: ", tabs[tab].groupname);
    for (int unit = 0; unit < eUnitNum; unit++)
    {
      if (units[unit].baseunit == tabs[tab].base)
      {
        printf("%s, ", units[unit].keyname);
      }
    }
    printf("\n");
  }
  
  printf("\n" "For bugreporting please see:\n"
         "<https://launchpad.net/qmetrics>\n");
}

int main(int argc, char* argv[])
{
  double inValue, outValue; 
  bool error = false;
  eUnit  inUnit, outUnit;
  char *pEnd;
  
  if (argc != 4)
  {
    fprintf(stderr, "Invalid number of parameters (%d instead of 3).\n", argc-1);
    printHelp();
    exit(1);    
  }
  
  inValue = strtod(argv[1], &pEnd);
  if (pEnd[0] != '\0')
  {
    fprintf(stderr, "Invalid input value: '%s'.\n", argv[1]);
    printHelp();
    exit(1);
  }

  inUnit  = unitID(argv[2]);
  if (eUnitNull == inUnit)
  {
    fprintf(stderr, "Invalid input unit: '%s'.\n", argv[2]);
    printHelp();
    exit(1);
  }

  outUnit = unitID(argv[3]);
  if (eUnitNull == outUnit)
  {
    fprintf(stderr, "Invalid output unit: '%s'.\n", argv[3]);
    printHelp();
    exit(1);
  }
    
  outValue = unitConvert(inValue, inUnit, outUnit, 0, &error);
  
  if (error)
  {
    fprintf(stderr, "Different unit types.\n");
    printHelp();
    exit(1);
  }
  
  printf("%e\n", outValue);
}
