/****************************************************************************
Copyright (C) 2010 Laszlo Simon <laszlo.simon@gmail.com>
This file is part of the QMETRICS project.

QMETRICS is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation version 3 of the License.

QMETRICS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with QMETRICS. If not, see <http://www.gnu.org/licenses/>.

See http://www.illusions.hu for further details.
*****************************************************************************/

#include <string.h>

#include "cm_units.h"

/** Array of unit definitions */
const sUnit units[eUnitNum] = 
{
#define QT_TR_NOOP(name) name
#ifdef  UNIT
#undef  UNIT
#endif
#define UNIT(key,name,base,conv,factor,offset,param) { eUnit##key, #key, name, eUnit##base, eConv##conv, (factor), (offset), param},
#include "cm_units.inc"
};

/** LookUp for unit ID of unit key named <keyname> */
eUnit unitID(char* keyname)
{
  eUnit result = eUnitNull;
  int unit;
  
  for (unit = 0; unit < eUnitNum; unit++)
  {
    if (strcmp(units[unit].keyname, keyname) == 0)
    {
      result = (eUnit)unit;
    }
  } 
  return(result);
}

/**  Converts <inValue> from <inUnit> to <outUnit> */
double unitConvert(double inValue, 
                   eUnit inUnit, 
                   eUnit outUnit, 
                   double constant,
                   bool *error)
{
  double outValue;
  double baseValue;
 
  /* error handling */ 
  if (error != NULL)
  {
    *error = false;
    if (units[inUnit].baseunit != units[outUnit].baseunit)
    {
      *error = true;
      return(0);
    }
  }
    
  /* Convert from original unit to base unit */
  switch (units[inUnit].conversion)
  {
    case eConvBase:       { baseValue = inValue;                                                  break; }  
    case eConvLinear:     { baseValue = (inValue - units[inUnit].offset) / units[inUnit].factor;  break; }  
    case eConvRecipr:     { baseValue = units[inUnit].factor / inValue;                           break; } 
    case eConvParam:      { baseValue = inValue / constant / units[inUnit].factor;                break; } 
    case eConvRecipParam: { baseValue = inValue * constant / units[inUnit].factor;                break; } 
    default: break;
  } 

  /* Convert from base unit to target unit */
  switch (units[outUnit].conversion)
  {
    case eConvBase:       { outValue = baseValue;                                                 break; }  
    case eConvLinear:     { outValue = baseValue * units[outUnit].factor + units[outUnit].offset; break; }  
    case eConvRecipr:     { outValue = units[outUnit].factor / baseValue;                         break; } 
    case eConvParam:      { outValue = baseValue * units[outUnit].factor * constant;              break; } 
    case eConvRecipParam: { outValue = baseValue * units[outUnit].factor / constant;              break; } 
    default: break;
  } 
  
  return outValue;
}
