/****************************************************************************
Copyright (C) 2010 Laszlo Simon <laszlo.simon@gmail.com>
This file is part of the QMETRICS project.

QMETRICS is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation version 3 of the License.

QMETRICS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with QMETRICS. If not, see <http://www.gnu.org/licenses/>.

See http://www.illusions.hu for further details.
*****************************************************************************/
#ifndef _CM_UNITS_H_
#define _CM_UNITS_H_

/** Conver type */
typedef enum
{
  /** the unit itself is a base unit f.i.: meter */
  eConvBase       = 0, 
  /** form of converting equation: 
        Unit = factor*Base+offset; Base = (Unit-offset) / factor */
  eConvLinear     = 1, 
  /** form of converting equation: Unit = factor / Base; Base = factor / Unit */  
  eConvRecipr     = 2,
  /** form of converting equation: Unit = factor * Base * UserParam; 
         (Conv - variable value given by the user in a special editbox f.i. viscosity)  */
  eConvParam      = 3,
  /** Unit = factor * Base / UserParam */
  eConvRecipParam = 4,
} eConvType;

typedef enum
{
#ifdef  UNIT
#undef  UNIT
#endif
#define UNIT(key,name,base,conv,factor,offset,param) eUnit##key,
#include "cm_units.inc"
  eUnitNum,
  eUnitNull
} eUnit;

/** Unit data table record*/
typedef struct
{
  eUnit       key;         /**< Primary key */
  const char *keyname;     /**< String contains primary key name */
  const char *name;        /**< Name (localization string) */
  eUnit       baseunit;    /**< Base of unit group that the unit belongs to */
  eConvType   conversion;  /**< Base unit conversion */
  double      factor;      /**< Constant for conversion */
  double      offset;      /**< Constant for conversion */
  const char *paramname;   /**< Name of conversion parameter for eConvParam, 
                                eConvReciParam type units */
} sUnit;

extern const sUnit units[eUnitNum];

extern eUnit unitID(char* keyname);

extern double unitConvert(double inValue, 
                          eUnit inUnit, 
                          eUnit outUnit, 
                          double constant,
                          bool *error);

#endif
