/****************************************************************************
Copyright (C) 2010 Laszlo Simon <laszlo.simon@gmail.com>
                   Esthefan Maleki <illusions.hu@gmail.com>
This file is part of the QMETRICS project.

QMETRICS is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation version 3 of the License.

QMETRICS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with QMETRICS. If not, see <http://www.gnu.org/licenses/>.

See http://www.illusions.hu for further details.
*****************************************************************************/
/*
  ID:       Keyword for the unit. Can contain only A-Z a-z chars.
  name:     English name of the unit. string type
  base:     ID of base unit the unit belongs to
  conv:     Conversion type: 
              Base :  the unit itself is a base
              Linear: Unit = factor*Base+offset; Base := (Unit-offset)/factor
              Recipr: Unit = offset+factor/Base; Base := factor/(Unit-offset)
              Param:  Unit = a*UserParam*Base
			  RecipParam Unit = a*Base/UserParam
  constant: Conversion constant
  offset:   Conversion offset
*/

/*             ID,                     name,        base,      conv,         constant,      offset,   paramname */
UNIT(       Meter,                  "Meter",         Meter,      Base,              1.0,          0.0,        "")
UNIT(       KiloMeter,              "Kilometer",     Meter,    Linear,              0.001,       0.0,        "")
UNIT(       DeciMeter,              "Decimeter",     Meter,    Linear,              10.0,        0.0,        "")
UNIT(       CentiMeter,             "Centimeter",    Meter,    Linear,              100.0,       0.0,        "")
UNIT(       MilliMeter,             "Millimeter",    Meter,    Linear,              1000.0,      0.0,        "")
UNIT(       MicroMeter,             "Micrometer",    Meter,    Linear,              1000000.0,   0.0,        "")
UNIT(       NanoMeter,              "Nanometer",     Meter,    Linear,              1000000000.0, 0.0,        "")
UNIT(       Angstrom,               "ngstrm",      Meter,    Linear,              10000000000.0, 0.0,        "")
UNIT(       Inch,                   "Inch",          Meter,    Linear,          1.0/0.0254,  0.0,        "")
UNIT(       Foot,                   "Foot",          Meter,    Linear,          1.0/0.3048, 0.0,        "")
UNIT(       Yard,                   "Yard",          Meter,    Linear,          1.0/0.9144, 0.0,        "")
UNIT(       Mile,                   "Mile (int)",    Meter,    Linear,          1.0/1609.344, 0.0,        "")
UNIT(       NauticalMile,           "Nautical mile", Meter,    Linear,          1.0/1852.0, 0.0,        "")
UNIT(       AU,                 "Astronomical unit", Meter,    Linear,      1.0/149597870691.0, 0.0,        "")
UNIT(       Lightyear,              "Lightyear",     Meter,    Linear,          1.0/9460730000000000.0, 0.0,        "")
UNIT(       Parsec,                 "Parsec",        Meter,    Linear,          1.0/30856780000000000.0, 0.0,        "")

UNIT(       Meter2Hertz,            "Null",               Meter,            Linear,        299792458.0,       0.0,        "")
UNIT(       Hertz,                  "Hertz",              Hertz,            Base,              1.0,       0.0,        "")
UNIT(       KiloHertz,              "Kilohertz",          Hertz,            Linear,            0.001,       0.0,        "")
UNIT(       MegaHertz,              "Megahertz",          Hertz,            Linear,            0.000001,       0.0,        "")
UNIT(       GigaHertz,              "Gigahertz",          Hertz,            Linear,            0.000000001,       0.0,        "")
UNIT(       TeraHertz,              "Terahertz",          Hertz,            Linear,            0.000000000001,       0.0,        "")
UNIT(       OnePerMinute,            "1/min",             Hertz,            Linear,            60.0,       0.0,        "")

UNIT(       SquareMeter,            "Square meter",        SquareMeter,      Base,              1.0,          0.0,        "")
UNIT(       SquareMilliMeter,       "Square millimeter",   SquareMeter,      Linear,              1000000.0,          0.0,        "")
UNIT(       SquareCentiMeter,       "Square centimeter",   SquareMeter,      Linear,              10000.0,          0.0,        "")
UNIT(       Hectare,                "Hectare",             SquareMeter,      Linear,              0.0001,          0.0,        "")
UNIT(       SquareKiloMeter,        "Square kilometer",    SquareMeter,      Linear,              1.0/1000000.0,          0.0,        "")
UNIT(       SquareInch,             "Square inch",         SquareMeter,      Linear,              10000.0/6.4516,          0.0,        "")
UNIT(       SquareFoot,             "Square Foot",         SquareMeter,      Linear,              1.0/0.09290304,          0.0,        "")
UNIT(       SquareYard,             "Square Yard",         SquareMeter,      Linear,              1.0/0.83612736,          0.0,        "")
UNIT(       Acre,                   "Acre",                SquareMeter,      Linear,              1.0/4046.8564224,          0.0,        "")
UNIT(       SquareMile,             "Squre mile",          SquareMeter,      Linear,              1.0/2589988.110336,          0.0,        "")
UNIT(       SquareClafter,          "Square clafter (hun)", SquareMeter,      Linear,              1.0/3.59665095538114,          0.0,        "")
UNIT(       CadastralAcre,          "Cadastral acre (hun)", SquareMeter,      Linear,              1.0/5754.64152860983296,          0.0,        "")

UNIT(       CubicMeter,             "Cubic meter",         CubicMeter,      Base,              1.0,          0.0,        "")
UNIT(       CubicMilliMeter,        "Cubic millimeter",    CubicMeter,      Linear,            1000000000.0,          0.0,        "")
UNIT(       CubicCentiMeter,        "Cubic centimeter",    CubicMeter,      Linear,            1000000.0,          0.0,        "")
UNIT(       Liter,                  "Liter",               CubicMeter,      Linear,            1000.0,          0.0,        "")
UNIT(       CubicInch,              "Cubic inch",          CubicMeter,      Linear,            1.0/0.000016387064,          0.0,        "")
UNIT(       CubicFoot,              "Cubic foot",          CubicMeter,      Linear,            1.0/0.028316846592,          0.0,        "")
UNIT(       CubicYard,              "Cubic yard",          CubicMeter,      Linear,            1.0/0.764554857984,          0.0,        "")
UNIT(       PintUS,                 "Pint (US)",           CubicMeter,      Linear,            2113.37629827347723,          0.0,        "")
UNIT(       GallonUS,               "Gallon (US)",         CubicMeter,      Linear,            1.0/0.003785412,          0.0,        "")
UNIT(       Barrel,              	"Barrel",          	   CubicMeter,      Linear,            1.0/0.158987304,          0.0,        "")

UNIT(       Second,                 "Second",              Second,      Base,                1.0,          0.0,        "")
UNIT(       Millenium,              "Millenium",           Second,      Linear,              1.0/31536000000.0,          0.0,        "")
UNIT(       Century,                "Century",             Second,      Linear,              1.0/3153600000.0,          0.0,        "")
UNIT(       Year,                   "Year",                Second,      Linear,              1.0/31536000.0,          0.0,        "")
UNIT(       LeapYear,               "Leap year",           Second,      Linear,              1.0/31622400.0,          0.0,        "")
UNIT(       Week,                   "Week",                Second,      Linear,              1.0/604800.0,          0.0,        "")
UNIT(       Day,                    "Day",                 Second,      Linear,              1.0/86400.0,          0.0,        "")
UNIT(       Minute,                 "Minute",              Second,      Linear,              1.0/60.0,          0.0,        "")
UNIT(       Hour,                   "Hour",                Second,      Linear,              1.0/3600.0,          0.0,        "")
UNIT(       MilliSecond,            "Millisecond",         Second,      Linear,         	   1000.0,          0.0,        "")
UNIT(       MicroSecond,            "Microsecond",         Second,      Linear,         	1000000.0,          0.0,        "")
UNIT(       NanoSecond,             "Nanosecond",          Second,      Linear,          1000000000.0,          0.0,        "")
UNIT(       PicoSecond,             "Picosecond",          Second,      Linear,       1000000000000.0,          0.0,        "")
UNIT(       FemtoSecond,            "FemtoSecond",         Second,      Linear,    1000000000000000.0,          0.0,        "")

UNIT(       MeterPerSecond,         "Meter / second",      MeterPerSecond,      Base,              1.0,          0.0,        "")
UNIT(       MilliMeterPerSecond,    "Millimeter / second", MeterPerSecond,      Linear,            1000.0,          0.0,        "")
UNIT(       CentiMeterPerSecond,    "Centimeter / second", MeterPerSecond,      Linear,            100.0,          0.0,        "")
UNIT(       MeterPerMinute,         "Meter / minute",      MeterPerSecond,      Linear,            60.0,          0.0,        "")
UNIT(       MeterPerHour,           "Meter / hour",        MeterPerSecond,      Linear,            3600.0,          0.0,        "")
UNIT(       KiloMeterPerHour,       "Kilometer / hour",    MeterPerSecond,      Linear,            3.6,          0.0,        "")
UNIT(       KiloMeterPerDay,        "Kilometer / day",     MeterPerSecond,      Linear,            86.4,          0.0,        "")
UNIT(       Knot,                   "Knot",                MeterPerSecond,      Linear,            3600.0/1852.0, 0.0,        "")
UNIT(       InchPerSecond,          "Inch / second",       MeterPerSecond,      Linear,            1.0/0.0254, 0.0,        "")
UNIT(       InchPerMinute,          "Inch / minute",       MeterPerSecond,      Linear,            60.0/0.0254, 0.0,        "")
UNIT(       FootPerMinute,          "Foot / minute",       MeterPerSecond,      Linear,            60.0/0.3048, 0.0,        "")
UNIT(       FootPerHour,            "Foot / hour",         MeterPerSecond,      Linear,            3600.0/0.3048, 0.0,        "")
UNIT(       MilePerHour,            "Mile / hour",         MeterPerSecond,      Linear,            3600.0/1609.344, 0.0,        "")
UNIT(       MilePerDay,             "Mile / day",          MeterPerSecond,      Linear,            86400.0/1609.344, 0.0,        "")
UNIT(       Mach15,                 "Mach (15C)",        MeterPerSecond,      Linear,            1.0/340.3, 0.0,        "")

UNIT(       Degree,                 "Degree",        Degree,      Base,              1.0,          0.0,        "")
UNIT(       DegreeSecond,           "Second",        Degree,    Linear,              3600.0,       0.0,        "")
UNIT(       DegreeMinute,           "Minute",        Degree,    Linear,              60.0,       0.0,        "")
UNIT(       Quadrant,               "Quadrant",      Degree,    Linear,              1.0/90.0,       0.0,        "")
UNIT(       Radian,                 "Radian",        Degree,    Linear,              0.0174532925199433,       0.0,        "")

UNIT(       Kilogram,                "Kilogram",     Kilogram,      Base,              1.0,          0.0,        "")
UNIT(       Milligram,               "Milligram",    Kilogram,     Linear,            1000000.0,          0.0,        "")
UNIT(       Gram,                    "Gram",         Kilogram,     Linear,            1000.0,          0.0,        "")
UNIT(       DekaGram,                "Dekagram",     Kilogram,     Linear,            100.0,          0.0,        "")
UNIT(       Quintal,                 "Quintal 100xkg", Kilogram,   Linear,            1.0/100.0,          0.0,        "")
UNIT(       MetricTon,               "Metric ton",   Kilogram,     Linear,            1.0/1000.0,          0.0,        "")
UNIT(       Pound,                   "Pound (Avoirdupois)",   Kilogram,     Linear,   1000.0/453.592338,          0.0,        "")
UNIT(       Ounce,                   "Ounce (Avoirdupois)",   Kilogram,     Linear,   1000.0/28.349521125,          0.0,        "")

UNIT(       KilogramPerCubicMeter,   "Kilogram / cubic meter",     KilogramPerCubicMeter,      Base,              1.0,          0.0,        "")
UNIT(       GramsPerCubicCentiMeter, "Grams / cubic centimeter",   KilogramPerCubicMeter,     Linear,            0.001,          0.0,        "")
UNIT(       PoundPerCubicFoot,       "Pound (Avoird.)/cubic foot", KilogramPerCubicMeter,     Linear,            0.062427964980308,          0.0,       "")

UNIT(       PascalSecond,           "Pa s = (N s)/m2 = kg/m s", PascalSecond,      Base,                1.0,          0.0,        "")
UNIT(       CentiPoise,             "CentiPoise",               PascalSecond,      Linear,                1000.0,          0.0,        "")
UNIT(       Lbfsperinch2,           "(lbf s) / inch2",          PascalSecond,      Linear,              1.0/6894.757,          0.0,        "")
UNIT(       Lbfsperft2,             "(lbf s) / ft2",            PascalSecond,      Linear,              1.0/47.88026,          0.0,        "")
UNIT(       Kgfsperm2,              "(kgf s) / m2",             PascalSecond,      Linear,              1.0/9.80665,          0.0,        "")
UNIT(       Lbmperfts,              "lbm / (ft s)",             PascalSecond,      Linear,              1.0/1.488164,          0.0,        "")
UNIT(       Dynspercm2,             "(dyn s)/cm2",              PascalSecond,      Linear,              10.0,          0.0,        "")
UNIT(       Lbmperfth,              "lbm / (ft h)",             PascalSecond,      Linear,              1.0/0.0004133789,          0.0,        "")

UNIT(       PascalSecond2M2PerS,    "Kg/m3",                PascalSecond,         RecipParam,          1.0,       0.0,        "Density [kg/m3]")
UNIT(       Meter2PerSecond,        "m2/s",                 Meter2PerSecond,      Base,                1.0,        0.0,        "")
UNIT(       MilliMeter2PerSecond,   "mm2/s",                Meter2PerSecond,      Linear,              1000000.0,        0.0,        "")
UNIT(       Meter2PerHour,          "m2/h",                	Meter2PerSecond,      Linear,              3600.0,        0.0,        "")
UNIT(       Foot2PerSecond,         "ft2/s",                Meter2PerSecond,      Base,                1.0/0.09290304,        0.0,        "")
UNIT(       Inch2PerSecond,         "inch2/s",              Meter2PerSecond,      Base,                10000.0/6.4516,        0.0,        "")
UNIT(       Foot2PerHour,           "ft2/h",                Meter2PerSecond,      Base,                3600.0/0.09290304,        0.0,        "")

UNIT(       KilogramPerKilogram,        "kg/kg",            KilogramPerKilogram,      Base,                1.0,        0.0,        "")
UNIT(       MilligramPerKilogram,       "mg/kg",            KilogramPerKilogram,      Linear,              1000000.0,        0.0,        "")
UNIT(       GramPerKilogram,            "gr/kg",            KilogramPerKilogram,      Linear,              1000.0,        0.0,        "")
UNIT(       MassFraction,            	"wt%",              KilogramPerKilogram,      Linear,              100.0,        0.0,        "")

UNIT(       CubicMeterPerCubicMeter,      "m3/m3",        CubicMeterPerCubicMeter,      Base,                1.0,        0.0,        "")
UNIT(       CubicCentiMeterPerCubicMeter, "cm3/m3",       CubicMeterPerCubicMeter,      Linear,           1000000.0,        0.0,        "")
UNIT(       CubicDeciMeterPerCubicMeter,  "dm3/m3",       CubicMeterPerCubicMeter,      Linear,           1000.0,        0.0,        "")
UNIT(       VolumetricFraction,           "vol%",         CubicMeterPerCubicMeter,      Linear,           100.0,        0.0,        "")

UNIT(       KiloMolPerCubicMeter,      "kmol/m3",         KiloMolPerCubicMeter,          Base,                1.0,        0.0,        "")
UNIT(       MolPerCubicMeter,          "mol/m3",          KiloMolPerCubicMeter,          Linear,              1000.0,        0.0,        "")
UNIT(       LbmolperUSgal,       "(lb mol) / US gal",     KiloMolPerCubicMeter,          Linear,              1.0/119.8264,        0.0,        "")
UNIT(       LbmolperUKgal,       "(lb mol) / UK gal",     KiloMolPerCubicMeter,          Linear,              1.0/99.77644,        0.0,        "")
UNIT(       Lbmolperft3,       "(lb mol) / cubic foot",   KiloMolPerCubicMeter,          Linear,              1.0/16.01846,        0.0,        "")

UNIT(       Kelvin,                     "Kelvin",         Kelvin,       			Base,                1.0,          0.0,        "")
UNIT(       DegreeCelsius,        "Celsius",             Kelvin,                   Linear,              1.0,          -273.15,        "")
UNIT(       DegreeFarhenheit,     "Fahrenheit",          Kelvin,                   Linear,              1.8,          -457.67,        "")
UNIT(       DegreeRankine,        "Rankine",    	      Kelvin,                   Linear,              1.8,          0,        "")
UNIT(       DegreeReaumur,        "Raumur",    	      Kelvin,                   Linear,              4.0/5.0,      -218.52,        "")

UNIT(       Pascal,                   "Pascal",           Pascal,       			Base,                1.0,          0.0,        "")
UNIT(       HectoPascal,              "HectoPascal",      Pascal,                   Linear,              0.01,          0.0,        "")
UNIT(       KiloPascal,               "KPa",              Pascal,                   Linear,              0.001,          0.0,        "")
UNIT(       MegaPascal,               "MPa",              Pascal,                   Linear,              0.000001,          0.0,        "")
UNIT(       MilliBarA,                "mbar (a)",         Pascal,                   Linear,              0.01,          0.0,        "")
UNIT(       MilliBarG,                "mbar (g)",         Pascal,                   Linear,              0.01,          -1000.0,        "")
UNIT(       BarA,                     "bar (a)",          Pascal,                   Linear,              0.00001,          0.0,        "")
UNIT(       BarG,                     "bar (g)",          Pascal,                   Linear,              0.00001,          -1.0,        "")
UNIT(       Atmosphere,               "Atmosphere",       Pascal,                   Linear,              1.0/101325.0,     0.0,        "")
UNIT(       Torr,                     "Torr",             Pascal,                   Linear,              1.0/0.0001333224,     0.0,        "")
UNIT(       InchesOfMercury0,         "Inches of mercury (0C)",  Pascal,           Linear,              1.0/3386.389,     0.0,        "")
UNIT(       MilliMeterWC,             "mm H2O",           Pascal,                   Linear,              1.0/9.80665,     0.0,        "")
UNIT(       MeterWC,                  "m H2O",            Pascal,                   Linear,              1.0/0.00980665,     0.0,        "")
UNIT(       AT,                       "at = kgf/cm2 = kp/cm2",    Pascal,           Linear,              1.0/0.000980665,     0.0,        "")
UNIT(       KpPerSquareMilliMeter,    "kp/mm2",           Pascal,                   Linear,              1.0/0.00000980665,     0.0,        "")
UNIT(       PSIA,                     "psi (a)",          Pascal,                   Linear,              1.0/6894.757,          0.0,        "")
UNIT(       PSIG,                     "psi (g)",          Pascal,                   Linear,              1.0/6894.757,   -100/6.894757,        "")

UNIT(       Joule,                   "Joule (Kg m^2/s^2)",  Joule,       			Base,                1.0,          0.0,        "")
UNIT(       KiloJoule,               "KiloJoule",           Joule,                  Linear,              0.001,          0.0,        "")
UNIT(       MegaJoule,               "MegaJoule",           Joule,                  Linear,              0.000001,          0.0,        "")
UNIT(       Calorie,                 "Calorie (IT)",        Joule,                  Linear,              1.0/4.1868,          0.0,        "")
UNIT(       KiloCalorie,             "Kilocalorie (IT)",    Joule,                  Linear,              0.001/4.1868,          0.0,        "")
UNIT(       KiloWattHour,            "Kilowatt hour",       Joule,                  Linear,              0.001/3600,          0.0,        "")
UNIT(       MegaWattHour,            "Megawatt hour",       Joule,                  Linear,              0.000001/3600,          0.0,        "")
UNIT(       HorsepowerHour,          "Horsepower hour",     Joule,                  Linear,              0.000001/2.64779568,          0.0,        "")
UNIT(       BTUIT,                   "Btu (IT)",            Joule,                  Linear,              0.001/1.055056,          0.0,        "")
UNIT(       ThermEC,                 "Therm (EC)",          Joule,                  Linear,              0.00000001/1.055056,          0.0,        "")
UNIT(       ThermUS,                 "Therm (US)",          Joule,                  Linear,              0.00000001/1.054804,          0.0,        "")

UNIT(       Newton,                   "Newton",  			Newton,       			Base,                1.0,          0.0,        "")
UNIT(       JoulePerCentimeter,       "Joule / centimeter", Newton,       			Linear,              100.0,          0.0,        "")
UNIT(       JoulePerMeter,       	  "Joule / meter",      Newton,       			Linear,              1.0,          0.0,        "")
UNIT(       PoundForce,       	      "Pound force",        Newton,       			Linear,              1.0/4.448222,          0.0,        "")
UNIT(       Dyne,       	          "Dyne",               Newton,       			Linear,              100000.0,          0.0,        "")
UNIT(       Poundal,       	          "Poundal",            Newton,       			Linear,              1.0/0.1382550,          0.0,        "")
UNIT(       Pond,       	          "Pond",               Newton,       			Linear,              1.0/0.00980665,          0.0,        "")
UNIT(       KiloPond,       	      "Kilopond",           Newton,       			Linear,              0.001/0.00980665,          0.0,        "")

UNIT(       CubicMeterPerSecond,        "m3/s",           CubicMeterPerSecond,       Base,                1.0,          0.0,        "")
UNIT(       CubicMeterPerMinute,        "m3/minute",      CubicMeterPerSecond,       Linear,              60.0,          0.0,        "")
UNIT(       CubicMeterPerHour,          "m3/hour",        CubicMeterPerSecond,       Linear,              3600.0,          0.0,        "")
UNIT(       LiterPerSecond,             "Liter/second",   CubicMeterPerSecond,       Linear,              1000.0,          0.0,        "")
UNIT(       LiterPerMinute,             "Liter/minute",   CubicMeterPerSecond,       Linear,              60000.0,          0.0,        "")
UNIT(       LiterPerHour,               "Liter/hour",     CubicMeterPerSecond,       Linear,              3600000.0,          0.0,        "")
UNIT(       CFM,               			"CFM",            CubicMeterPerSecond,       Linear,              1.0/0.00047195,          0.0,        "")
UNIT(       USgpd,               		"US gpd",         CubicMeterPerSecond,       Linear,              1.0/0.00000004381264,          0.0,        "")
UNIT(       USgpm,               		"US gpm",         CubicMeterPerSecond,       Linear,              1.0/0.0000630902,          0.0,        "")
UNIT(       Impgpd,               		"Imperial gpd",   CubicMeterPerSecond,       Linear,              1.0/5.26167826388889E-08,          0.0,        "")
UNIT(       Impgpm,               		"Imperial gpm",   CubicMeterPerSecond,       Linear,              1.0/0.000075768167,          0.0,        "")
UNIT(       CubicFootPerHour,           "Cubic foot / hour",   CubicMeterPerSecond,  Linear,              1.0/0.00000786579072,          0.0,        "")

UNIT(       CubicMeter2Kilogram,    "Kg/m3",               CubicMeterPerSecond,      Param,               1.0,       0.0,        "Density [kg/m3]")
UNIT(       KilogramPerSecond,      "Kilogram/second",     KilogramPerSecond,        Base,                1.0,        0.0,        "")
UNIT(       Gram2PerSecond,   		"Gram/s",              KilogramPerSecond,        Linear,              1000.0,        0.0,        "")
UNIT(       KilogramPerMinute,      "Kilogram/minute",     KilogramPerSecond,        Linear,              60.0,        0.0,        "")
UNIT(       KilogramPerHour,        "Kilogram/hour",       KilogramPerSecond,        Linear,              3600.0,        0.0,        "")
UNIT(       PoundPerHour,           "PoundPerHour (lb/h)", KilogramPerSecond,        Linear,              7936.64199856920864,        0.0,        "")

