
#include <cstdio>
#include <cfloat>

#include <QGroupBox>
#include <QTabWidget>
#include <QLabel>
#include <QLineEdit>
#include <QSignalMapper>

#include "qm_about.h"

#include "cm_units.h"
#include "cm_tabs.h"

#include "qm_mainwnd.h"
#include "ui_qm_mainwnd.h"

qm_mainwnd::qm_mainwnd(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::qm_mainwnd)
{
  QGridLayout *layouts[eTabNum];
  QHBoxLayout *tablayouts[eTabNum];
  int tabLookup[eUnitNum];

  QSignalMapper *signalMapper = new QSignalMapper(this);

  ui->setupUi(this);

  // create tabs with horizontal layout
  for (int i = 0; i < eTabNum; i++)
  {
    tabLookup[tabs[i].base] = i;

    if (tabs[i].contact == eUnitNull)
    {
      ui->listWidget->addItem(tr(tabs[i].name));
      QWidget *widget = new QWidget;
      ui->stackedWidget->addWidget(widget);
      QHBoxLayout *layout = new QHBoxLayout;
      widget->setLayout(layout);
      tablayouts[i] = layout;
    }
  }

  // create groupboxes with grid layout, 
  for (int i = 0; i < eTabNum; i++)
  {
    QGroupBox *groupBox = new QGroupBox(this);
    groupBox->setTitle(tr(tabs[i].groupname));

    QGridLayout *layout = new QGridLayout;
    groupBox->setLayout(layout);

    int tabLayoutIndex = (tabs[i].contact != eUnitNull)
                         ? tabLookup[tabs[i].contact]
                         : tabLookup[tabs[i].base];

    tablayouts[tabLayoutIndex]->addWidget(groupBox);

    layouts[i] = layout;
    layout->setColumnStretch(2,1);
    
    /* add parameter lineEdit to tab if necessary */
    if (  (units[tabs[i].conversion].conversion == eConvParam) ||
          (units[tabs[i].conversion].conversion == eConvRecipParam)  )
    {
      QLabel    *label    = new QLabel(tr(units[tabs[i].conversion].paramname));      
      QLineEdit *param = new QLineEdit;
      param->setText("1.0");
      param->setValidator(new QDoubleValidator(DBL_MIN, DBL_MAX, INT_MAX, param));
      layouts[i]->addWidget(param, 0, 0);
      layouts[i]->addWidget(label, 0, 1);
      
      signalMapper->setMapping(param, QString(units[tabs[i].conversion].keyname));
      connect(param,        SIGNAL(textEdited(const QString &)),
              signalMapper, SLOT (map()));
            
      QFrame *line = new QFrame;
      line->setFrameShape(QFrame::HLine);
      line->setFrameShadow(QFrame::Sunken);
      layouts[i]->addWidget(line, 1, 0);
      
      params[i] = param;
    }
  }

  // create input objects and add the to corresponding group
  for (int i = 0; i < eUnitNum; i++)
  {
    bool convUnit = false;
    for (int j = 0; j < eTabNum; j++) convUnit |= (tabs[j].conversion == i);
    
    QLabel    *label    = new QLabel(tr(units[i].name));
    QLineEdit *lineEdit = new QLineEdit;

    double init = unitConvert(1.0, units[i].baseunit, (eUnit)i, 1.0, NULL);
    QString initStr; initStr.setNum(init, 'g', 10);
    lineEdit->setText(initStr);
    lineEdit->setValidator(new QDoubleValidator(DBL_MIN, DBL_MAX, INT_MAX, lineEdit));

    int tab = tabLookup[units[i].baseunit];
    int row = layouts[tab]->rowCount();
        
    if (convUnit) 
    { 
       lineEdit->hide(); 
       label->hide();
    }
    else
    {
      layouts[tab]->addWidget(lineEdit, row, 0);
      layouts[tab]->addWidget(label   , row, 1);

      signalMapper->setMapping(lineEdit, QString(units[i].keyname));
      connect(lineEdit,     SIGNAL(textEdited(const QString &)),
              signalMapper, SLOT (map()));
    }
    lineEdits[i] = lineEdit;
  }

  connect(signalMapper, SIGNAL(mapped(const QString &)),
          this, SLOT(on_anyLineEdit_textEdited(const QString &)));

  // set additional empty col and row for each group for resize purpose
  for (int i = 0; i < eTabNum; i++)
  {
    layouts[i]->setRowStretch(layouts[i]->rowCount(),1);
    layouts[i]->setColumnStretch(layouts[i]->columnCount(),1);
  }

  connect(ui->listWidget, SIGNAL(currentRowChanged(int)),
          ui->stackedWidget, SLOT(setCurrentIndex(int)));

  connect(ui->actionQuit, SIGNAL(triggered()),
          this, SLOT(close()));

  connect(ui->actionGroups, SIGNAL(toggled(bool)),
          ui->dockWidget, SLOT(setVisible(bool)));
  connect(ui->dockWidget, SIGNAL(visibilityChanged(bool)),
          ui->actionGroups, SLOT(setChecked(bool)));
}

qm_mainwnd::~qm_mainwnd()
{
  delete ui;
}

void qm_mainwnd::on_anyLineEdit_textEdited(const QString &unit)
{
  eUnit inUnit  = unitID((char *)unit.toStdString().c_str());
  double inValue = this->lineEdits[inUnit]->text().toDouble();
  double outValue;
  bool error;

  for (int i = 0; i < eUnitNum; i++)
  {
    // if 'unit' is tab conversion unit of 'i''s unit group
    if (tabs[tabID(units[i].baseunit)].conversion == inUnit)
    {      
      double param = 1.0;
      if (   (units[inUnit].conversion == eConvParam)
          || (units[inUnit].conversion == eConvRecipParam)  )
      {
        param = this->params[tabID(units[i].baseunit)]->text().toDouble();
      }
      inValue = this->lineEdits[tabs[tabID(units[i].baseunit)].contact]->text().toDouble();
      outValue = unitConvert(inValue, tabs[tabID(units[i].baseunit)].contact, inUnit, param, &error);   
      outValue = unitConvert(outValue, units[i].baseunit, (eUnit)i, 1.0, &error);
      
      QString outStr; outStr.setNum(outValue, 'g', 10);
      this->lineEdits[i]->setText(outStr);
    }
    // if 'i' and 'unit' are same unit group and not the same unit 
    else if ((i != inUnit) && (units[i].baseunit ==  units[inUnit].baseunit))
    {
      outValue = unitConvert(inValue, inUnit, (eUnit)i, 1.0, &error);
      
      QString outStr; outStr.setNum(outValue, 'g', 10);
      this->lineEdits[i]->setText(outStr);
    }
    // if 'i' is unit co-group of 'unit''s group
    else if ((tabs[tabID(units[i].baseunit)].contact == units[inUnit].baseunit))
    {
      double param = 1.0;
      if (   (units[tabs[tabID(units[i].baseunit)].conversion].conversion == eConvParam)
          || (units[tabs[tabID(units[i].baseunit)].conversion].conversion == eConvRecipParam)  )
      {
        param = this->params[tabID(units[i].baseunit)]->text().toDouble();
      }
      
      outValue = unitConvert(inValue, inUnit, tabs[tabID(units[i].baseunit)].conversion, param, &error);      
      outValue = unitConvert(outValue, units[i].baseunit, (eUnit)i, 1.0, &error);
      
      QString outStr; outStr.setNum(outValue, 'g', 10);
      this->lineEdits[i]->setText(outStr);
    }
    // if 'unit' is in co-group of 'i''s group
    else if ((tabs[tabID(units[inUnit].baseunit)].contact == units[i].baseunit))
    {
      double param = 1.0;
      if (   (units[tabs[tabID(units[inUnit].baseunit)].conversion].conversion == eConvParam)
          || (units[tabs[tabID(units[inUnit].baseunit)].conversion].conversion == eConvRecipParam)  )
      {
        param = this->params[tabID(units[inUnit].baseunit)]->text().toDouble();
      }
      
      outValue = unitConvert(inValue, inUnit, units[inUnit].baseunit, 1.0, &error);
      outValue = unitConvert(outValue, tabs[tabID(units[inUnit].baseunit)].conversion, (eUnit)i, param, &error);
      
      QString outStr; outStr.setNum(outValue, 'g', 10);
      this->lineEdits[i]->setText(outStr);
    }
  }
}

void qm_mainwnd::changeEvent(QEvent *e)
{
  QMainWindow::changeEvent(e);
  switch (e->type()) {
  case QEvent::LanguageChange:
    ui->retranslateUi(this);
    break;
  default:
    break;
  }
}

void qm_mainwnd::on_actionAbout_triggered()
{
  qm_about about;
  about.exec();
}
